SQLAlchemy 0.5 Documentation - module sqlalchemy.databases.sqlite

# SQLAlchemy 0.5 Documentation

Multiple Pages | One Page
Version: 0.5.0rc3 Last Updated: 11/07/08 13:55:35

### module sqlalchemy.databases.sqlite

### class DateTimeMixin(object)

back to section top

### class DefaultClause(FetchedValue)

A DDL-specified DEFAULT column value.

def __init__(self, arg, for_update=False)

Construct a new `DefaultClause`.

back to section top

### class NoneType(object)

back to section top

### class SLBinary(Binary)

def get_col_spec(self)
back to section top

### class SLBoolean(Boolean)

def bind_processor(self, dialect)
def get_col_spec(self)
def result_processor(self, dialect)
back to section top

### class SLChar(SLUnicodeMixin,CHAR)

def get_col_spec(self)
back to section top

### class SLDate(DateTimeMixin,Date)

def bind_processor(self, dialect)
def get_col_spec(self)
def result_processor(self, dialect)
back to section top

### class SLDateTime(DateTimeMixin,DateTime)

def bind_processor(self, dialect)
def get_col_spec(self)
def result_processor(self, dialect)
back to section top

### class SLFloat(Float)

def bind_processor(self, dialect)
def get_col_spec(self)
back to section top

### class SLInteger(Integer)

def get_col_spec(self)
back to section top

### class SLNumeric(Numeric)

def bind_processor(self, dialect)
def get_col_spec(self)
back to section top

### class SLSmallInteger(SmallInteger)

def get_col_spec(self)
back to section top

### class SLString(SLUnicodeMixin,String)

def get_col_spec(self)
back to section top

### class SLText(SLUnicodeMixin,Text)

def get_col_spec(self)
back to section top

### class SLTime(DateTimeMixin,Time)

def bind_processor(self, dialect)
def get_col_spec(self)
def result_processor(self, dialect)
back to section top

### class SLUnicodeMixin(object)

def bind_processor(self, dialect)
def result_processor(self, dialect)
back to section top

### class SQLiteCompiler(DefaultCompiler)

def for_update_clause(self, select)
def limit_clause(self, select)
def visit_cast(self, cast, **kwargs)
back to section top

### class SQLiteDialect(DefaultDialect)

def __init__(self, **kwargs)

Construct a new `SQLiteDialect`.

def create_connect_args(self, url)
def create_execution_context(self, connection, **kwargs)
def dbapi(cls)
def has_table(self, connection, table_name, schema=None)
def is_disconnect(self, e)
def reflecttable(self, connection, table, include_columns)
def server_version_info(self, connection)
def table_names(self, connection, schema)
def type_descriptor(self, typeobj)
back to section top

### class SQLiteExecutionContext(DefaultExecutionContext)

def post_exec(self)
back to section top

### class SQLiteIdentifierPreparer(IdentifierPreparer)

def __init__(self, dialect)

Construct a new `SQLiteIdentifierPreparer`.

back to section top

### class SQLiteSchemaDropper(SchemaDropper)

back to section top

### class SQLiteSchemaGenerator(SchemaGenerator)

def get_column_specification(self, column, **kwargs)
back to section top